# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property
from abc import abstractmethod

import winrt._winrt
import winrt.system

Self = typing.TypeVar('Self')

@typing.final
class DisplayAdapterId:
    @_property
    def low_part(self) -> winrt.system.UInt32: ...
    @_property
    def high_part(self) -> winrt.system.Int32: ...
    def __new__(cls, low_part: winrt.system.UInt32 = 0, high_part: winrt.system.Int32 = 0) -> DisplayAdapterId: ...
    def __replace__(self, /, **changes: typing.Any) -> DisplayAdapterId: ...
    def unpack(self) -> typing.Tuple[winrt.system.UInt32, winrt.system.Int32]: ...

@typing.final
class DisplayId:
    @_property
    def value(self) -> winrt.system.UInt64: ...
    def __new__(cls, value: winrt.system.UInt64 = 0) -> DisplayId: ...
    def __replace__(self, /, **changes: typing.Any) -> DisplayId: ...

@typing.final
class PointInt32:
    @_property
    def x(self) -> winrt.system.Int32: ...
    @_property
    def y(self) -> winrt.system.Int32: ...
    def __new__(cls, x: winrt.system.Int32 = 0, y: winrt.system.Int32 = 0) -> PointInt32: ...
    def __replace__(self, /, **changes: typing.Any) -> PointInt32: ...
    def unpack(self) -> typing.Tuple[winrt.system.Int32, winrt.system.Int32]: ...

@typing.final
class RectInt32:
    @_property
    def x(self) -> winrt.system.Int32: ...
    @_property
    def y(self) -> winrt.system.Int32: ...
    @_property
    def width(self) -> winrt.system.Int32: ...
    @_property
    def height(self) -> winrt.system.Int32: ...
    def __new__(cls, x: winrt.system.Int32 = 0, y: winrt.system.Int32 = 0, width: winrt.system.Int32 = 0, height: winrt.system.Int32 = 0) -> RectInt32: ...
    def __replace__(self, /, **changes: typing.Any) -> RectInt32: ...
    def unpack(self) -> typing.Tuple[winrt.system.Int32, winrt.system.Int32, winrt.system.Int32, winrt.system.Int32]: ...

@typing.final
class SizeInt32:
    @_property
    def width(self) -> winrt.system.Int32: ...
    @_property
    def height(self) -> winrt.system.Int32: ...
    def __new__(cls, width: winrt.system.Int32 = 0, height: winrt.system.Int32 = 0) -> SizeInt32: ...
    def __replace__(self, /, **changes: typing.Any) -> SizeInt32: ...
    def unpack(self) -> typing.Tuple[winrt.system.Int32, winrt.system.Int32]: ...

@typing.final
class _IGeometrySource2D: ...

class IGeometrySource2D(winrt._winrt.IInspectable):  # type: ignore[misc]
    pass




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import winrt.system
from winrt._winrt_windows_graphics import (
    DisplayAdapterId,
    DisplayId,
    PointInt32,
    RectInt32,
    SizeInt32,
    _IGeometrySource2D,
    IGeometrySource2D,
)

__all__ = [
    "DisplayAdapterId",
    "DisplayId",
    "PointInt32",
    "RectInt32",
    "SizeInt32",
    "IGeometrySource2D",
]

